@@ -2,8 +2,8 @@ from notecoin.database.base import Base, BaseTable
 from sqlalchemy import BIGINT, Column, Float, String
 
 
-class OkexSocketPublicTickers(Base, BaseTable):
-    __tablename__ = 'okex_socket_public_tickets'
+class OkexClientAccountBalance(Base, BaseTable):
+    __tablename__ = 'okex_client_account_balance'
     ccy = Column(String(120), comment='币种', primary_key=True)
     eq = Column(Float(), comment='币种总权益', primary_key=True)
     cashBal = Column(Float(), comment='币种余额')
@@ -28,12 +28,11 @@ class OkexSocketPublicTickers(Base, BaseTable):
     stgyEq = Column(Float(), comment='策略权益')
     isoUpl = Column(Float(), comment='逐仓未实现盈亏')
 
-    ts = Column(BIGINT(), comment='数据产生时间，Unix时间戳的毫秒数格式')
-
     def __init__(self, *args, **kwargs):
         self.ccy = kwargs.get("ccy")
-        self.eq = kwargs.get("eq", "")
+        self.eq = kwargs.get("eq", 0)
         self.cashBal = kwargs.get("cashBal", 0)
+        self.uTime = kwargs.get("uTime", 0)
         self.isoEq = kwargs.get("isoEq", 0)
         self.availEq = kwargs.get("availEq", 0)
         self.disEq = kwargs.get("disEq", 0)
